﻿#ifndef CMAP_H
#define CMAP_H

//#define CONVERT_MAP 1

#include <QImage>
#include <QColor>
#include "system/cmaths.h"
#include <vector>

#define TILE_SIZE   32

enum EWallSide
{
    eWallSideUp = 0,
    eWallSideDown,
    eWallSideLeft,
    eWallSideRight,
    eWallSideMax
};

enum EParamType
{
    eParamOrnate = 0,
};

//---------------------------------------------------------------------------------------------
struct CParamType
{
    EParamType  mType;
    QString     mName;
};

//---------------------------------------------------------------------------------------------
class CParam
{
public:
    EParamType  mType;
};

class CParamOrnate : CParam
{
public:
    CParamOrnate();
    uint8_t mValue;
};

//---------------------------------------------------------------------------------------------
class CWall
{
public:
    CWall();
    virtual ~CWall();

    void    setType(uint8_t type);
    uint8_t getType();
    CWall&  operator=(CWall& rhs);
    void    load(FILE* handle);
    void    save(FILE* handle);

    std::vector<CParam*>    mParams;

private:
    void    deleteParams();

    uint8_t mType;
};

//---------------------------------------------------------------------------------------------
class CTile
{
public:
    CTile();

    CTile&  operator=(CTile& rhs);

    CWall   mWalls[eWallSideMax];
    uint8_t mType;
};

//---------------------------------------------------------------------------------------------
class CMap
{
public:
    CMap();
    ~CMap();

    void    resize();

    void    setTile(CVec2 pos, uint8_t type);
    void    setWall(CVec2 pos, EWallSide side, uint8_t type);

    void    save(char* fileName);
    void    load(char* fileName);
    bool    isLoaded();

    CTile*  getTile(CVec2 pos);

    CVec2   mSize;
    std::vector<std::vector<CParamType>>  mWallsParams; // liste des paramètres pour chaque type de mur

private:
    CTile*  mTiles;
};

extern CMap  map;

#endif // CMAP_H
