﻿#include "clipboard.h"
#include "editor.h"

CClipboard::CClipboard()
{
    mMem = NULL;
}

CClipboard::~CClipboard()
{
    clear();
}

void CClipboard::clear()
{
    if (mMem != NULL)
        delete[] mMem;
}

bool CClipboard::isEmpty()
{
    return (mMem == NULL);
}

void CClipboard::copyFromMap(CVec2 mousePos, CVec2 size, ETabIndex tabIndex)
{
    CVec2 pos = mousePos / TILE_SIZE;

    if (pos.x + size.x > map.mSize.x)
        size.x = map.mSize.x - pos.x;

    if (pos.y + size.y > map.mSize.y)
        size.y = map.mSize.y - pos.y;

    if (size.x == 0 || size.y == 0)
        return;

    mType = eTabTiles;

    switch (tabIndex)
    {
    case eTabWalls:
        if (editor.isSelectSingleWall() == true)
        {
            mType = eTabWalls;
            mSide = editor.getWallSideAbs(mousePos);
        }
        break;

    case eTabObjects:
        if (editor.isSelectSingleObject() == true)
        {
            mType = eTabObjects;
        }
        break;

    default:
        break;
    }

    clear();
    mSize = size;
    mMem = new CTile[mSize.x * mSize.y];

    if (mMem != NULL)
        for (int y = 0; y < mSize.y; ++y)
            for (int x = 0; x < mSize.x; ++x)
                mMem[y * mSize.x + x] = *map.getTile(CVec2(pos.x + x, pos.y + y));
}

void CClipboard::copyFromClip(CClipboard* src)
{
    clear();

    if (src->isEmpty() == true)
        return;

    mType = src->mType;
    mSide = src->mSide;
    mSize = src->mSize;
    mMem = new CTile[mSize.x * mSize.y];

    if (mMem != NULL)
        for (int i = 0; i < mSize.x * mSize.y; ++i)
            mMem[i] = src->mMem[i];
}

void CClipboard::copyToMap(CVec2 mousePos, ETabIndex index)
{
    CVec2   pos = mousePos / TILE_SIZE;

    if (mType == eTabTiles)
    {
        // une ou plusieurs cases
        for (int y = 0; y < mSize.y; ++y)
            for (int x = 0; x < mSize.x; ++x)
            {
                CTile*  tile = map.getTile(CVec2(pos.x + x, pos.y + y));

                if (tile != NULL)
                {
                    if (index == eTabTiles)
                    {
                        tile->mType = mMem[y * mSize.x + x].mType;
                    }
                    else if (index == eTabWalls)
                    {
                        for (int i = 0; i < eWallSideMax; ++i)
                            tile->mWalls[i] = mMem[y * mSize.x + x].mWalls[i];
                    }
                }
            }
    }
    else if (mType == eTabWalls)
    {
        // un mur
        CTile*      tile = map.getTile(pos);
        EWallSide   side = editor.getWallSideAbs(mousePos);
        tile->mWalls[side] = mMem[0].mWalls[mSide];
    }
    else if (mType == eTabObjects)
    {
        // une case d'objets
    }
}
