﻿#ifndef INTERFACE_H
#define INTERFACE_H

#include <QTimer>
#include <QImage>
#include "../common/sources/system/cmaths.h"
#include "character.h"
#include "mouse.h"

#define MAIN_INTERFACE_COLOR    QColor(0, 204, 204)

#define CHAMP_PORTRAIT_WIDTH    32
#define CHAMP_PORTRAIT_HEIGHT   29
#define ITEM_WIDTH    16
#define ITEM_HEIGHT   16

class CInterface
{
public:
    // Etat principal de l'interface
    enum EMainState
    {
        eMainGame = 0,  // fenêtre standard avec la vue 3D
        eMainInventory  // écran d'inventaire
    };

    // Etats de la zone des armes
    enum EWeaponsAreaState
    {
        eWeaponsAreaWeapons = 0,    // Les 4 zones d'armes
        eWeaponsAreaAttacks,        // Les attaques d'une arme
        eWeaponsAreaDamage          // Les dommages quend on frappe un monstre
    };

    // polices de caractères
    enum EFonts
    {
        eFontStandard = 0,
        eFontScroll,
        eFontWalls
    };

    CInterface();
    ~CInterface();

    void    display(QImage* image);
    void    update(SMouseArea *clickedArea);
    bool    isInInventory();
    CRect   getChampionPortraitRect(int num);
    CRect   getItemRect(int num);
    void    drawText(QImage* image, CVec2 pos, EFonts font, const char* text, QColor color);

private:
    bool    isChampionEmpty(int num);
    bool    isChampionDead(int num);

    bool    isWeaponEmpty(int num);
    bool    isWeaponGreyed(int num);

    bool    isArrowsGreyed();

    void    drawBar(QImage* image, int num, CVec2 pos, CCharacter::EStatsNames statName);
    void    drawChampion(QImage* image, int num);
    void    drawSpells(QImage* image);
    void    drawWeaponsArea(QImage* image);
    void    drawWeapon(QImage* image, int num);
    void    drawArrows(QImage* image);
    void    drawInventory(QImage* image);
    void    greyRectangle(QImage* image, CRect rect);
    int     getWeapon(int num);
    CRect   getBodyPartRect(CCharacter::EBodyParts part);
    CCharacter::SStat   getStat(int num, CCharacter::EStatsNames statName);

    EMainState          mainState;
    EWeaponsAreaState   weaponsAreaState;
    int     currentChampion;
    int     currentWeapon;
    QTimer* weaponCoolDown[4];
};

extern CInterface   interface;

#endif // INTERFACE_H
